=====
entry
=====

.. automodule:: cmkinitramfs.entry
   :platform: Linux

.. autoclass:: Config
   :members:
   :show-inheritance:

.. autofunction:: read_config

.. autofunction:: entry_cmkinit

.. autofunction:: entry_findlib

.. autofunction:: entry_cmkcpiolist

.. autofunction:: entry_cmkcpiodir

